var assert = require('assert');
pwf = require('pwf.js');

describe('compat module', function() {
	before(require('./utils/create_env'));

	it('tests el method', function() {
		var
			el   = pwf.jquery.el('ul',   'ul-cname'),
			div  = pwf.jquery.el('div',  'div-cname'),
			span = pwf.jquery.el('span', 'span-cname');

		assert.equal(el.is('ul'), true);
		assert.equal(el.hasClass('ul-cname'), true);

		assert.equal(div.is('div'), true);
		assert.equal(div.hasClass('div-cname'), true);

		assert.equal(span.is('span'), true);
		assert.equal(span.hasClass('span-cname'), true);
	});


	it('tests strip_tags method', function() {
		assert.equal(typeof pwf.strip_tags, 'function');
		assert.strictEqual(pwf.strip_tags, pwf.jquery.strip_tags);

		assert.equal(pwf.jquery.strip_tags('asdf'), 'asdf');
		assert.equal(pwf.jquery.strip_tags('<asdf/>'), '');
		assert.equal(pwf.jquery.strip_tags('<a>asdf</a>'), 'asdf');
		assert.equal(pwf.jquery.strip_tags(pwf.jquery('<a/>').html('<p>asdf</p>')), 'asdf');
	});


	it('tests create_els method', function() {
		var
			el1  = pwf.jquery.div('div-cname'),
			el2  = pwf.jquery.div('div-cname'),
			list = ['a', 'b', 'c'];

		el1.create_divs(list);
		el2.create_divs(list, 'prefix');

		for (var i = 0; i < list.length; i++) {
			assert.equal(el1[list[i]] instanceof pwf.jquery, true);
			assert.equal(el1[list[i]].hasClass(list[i]), true);

			assert.equal(el2[list[i]] instanceof pwf.jquery, true);
			assert.equal(el2[list[i]].hasClass('prefix-' + list[i]), true);
		}

	});
});
